@@ -18,9 +18,11 @@ OC.L10N.register(
     "Delete note" : "Borrar nota",
     "Remove from favorites" : "Eliminar de favoritos",
     "Add to favorites" : "Agregar a favoritos",
+    "Error during preparing note for deletion." : "Error al preparar la nota para el borrado.",
     "Use current version" : "Usar la versión actual",
     "Edit" : "Editar",
     "Preview" : "Previsualizar",
+    "Exit full screen" : "Salir de pantalla completa",
     "Today" : "Hoy",
     "Yesterday" : "Ayer",
     "This week" : "Esta semana",
