@@ -3,7 +3,8 @@ OC.L10N.register(
     {
     "Notes" : "Notizen",
     "Error" : "Fehler",
-    "Details" : "Detailer",
+    "Share" : "Deelen",
+    "Rename" : "Rename",
     "Remove from favorites" : "Remove from favorites",
     "Add to favorites" : "Add to favorites",
     "Edit" : "Änneren",
