@@ -8,7 +8,7 @@ OC.L10N.register(
     "All notes" : "Visas piezīmes",
     "Categories" : "Kategorijas",
     "No notes yet" : "Nav nevienas piezīmes",
-    "Details" : "Detaļas",
+    "Share" : "Koplietot",
     "Delete note" : "Dzēst piezīmi",
     "Remove from favorites" : "Noņemt no izlases",
     "Add to favorites" : "Pievienot izlasei",
@@ -18,10 +18,8 @@ OC.L10N.register(
     "Yesterday" : "Vakar",
     "This week" : "Šonedēļ",
     "This month" : "Šis mēnesis",
-    "Category" : "Kategorija",
-    "Uncategorized" : "Bez kategorijas",
-    "_%n word_::_%n words_" : ["%n words","%n vārdi","%n vārdi"],
     "Updating settings has failed." : "Iestatījumu atjaunināšana neizdevās.",
+    "Uncategorized" : "Bez kategorijas",
     "Tasks" : "Uzdevumi"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
