@@ -32,8 +32,14 @@ OC.L10N.register(
     "Action" : "Действие",
     "Mobile apps" : "Мобильные приложения",
     "User defined" : "Определено пользователем",
+    "Open in rich text mode" : "Открыть в текстовом режиме",
     "Open in edit mode" : "Открыть в режиме редактирования",
     "Open in preview mode" : "Открыть в режиме просмотра",
+    "CTRL" : "CTRL",
+    "Make the selection bold" : "Сделайте выделение жирным",
+    "Make the selection italic" : "Сделайте выделение курсивом",
+    "Wrap the selection in quotes" : "Заключите выделение в кавычки",
+    "ALT" : "ALT",
     "Insert link" : "Вставить ссылку",
     "Insert image" : "Вставить изображение",
     "Switch between editor and viewer" : "Переключиться между редактированием и просмотром",
@@ -46,7 +52,7 @@ OC.L10N.register(
     "Wrong image" : "Неверное изображение",
     "The file was not uploaded. Check your server logs." : "Файл не был загружен. Проверьте журналы вашего сервера.",
     "Install the app for your mobile phone in order to access your notes from everywhere." : "Для доступа к заметкам с телефона установите мобильное приложение.",
-    "Details" : "Подробнее",
+    "Share" : "Публикация",
     "Delete note" : "Удалить заметку",
     "Remove from favorites" : "Убрать из избранного",
     "Add to favorites" : "Добавить в избранное",
@@ -74,20 +80,8 @@ OC.L10N.register(
     "Last week" : "За последнюю неделю",
     "This month" : "Этот месяц",
     "Last month" : "За последний месяц",
-    "Category" : "Категория",
-    "Uncategorized" : "Без категории",
-    "Set category" : "Задать категорию",
-    "Click here to save manually" : "Нажмите для принудительного сохранения",
-    "Saving failed!" : "Не удалось сохранить",
-    "Last modified: {date}" : "Последнее изменение: {date}",
-    "Note has unsaved changes" : "Заметка содержит несохраненные изменения",
-    "Subcategory" : "Подкатегория",
-    "Click to edit title" : "Нажмите, чтобы изменить заголовок",
-    "_%n word_::_%n words_" : ["%n слово","%n слова","%n слов","%n слов"],
-    "_%n character_::_%n characters_" : ["%n символ","%n символа","%n символов","%n символов"],
     "Use Markdown markups to style your text." : "Поддержка языка разметки Markdown для оформления текста;",
     "Start writing a note by clicking on “{newnote}” in the app navigation." : "Чтобы создать заметку, нажмите «{newnote}» в панели навигации.",
-    "You can create subcategories by using “/” as delimiter between parent category and subcategory, e.g. “{parent}/{sub}”." : "Для создания вложенных категорий используйте разделитель «/», например: «{parent}/{sub}».",
     "Note not found." : "Заметка не найдена",
     "Note is locked." : "Заметка заблокирована",
     "Insufficient storage." : "Ндостаточно места",
@@ -106,8 +100,10 @@ OC.L10N.register(
     "Toggling favorite for note {id} has failed." : "Не удалось установить отметку «избранное» для заметки {id}.",
     "Updating the note's category has failed. Is the target directory writable?" : "Ошибка обновления категории заметки. Разрешена ли запись в целевую директорию?",
     "Updating the category for note {id} has failed." : "Не удалось обновить категорию для заметки {id}.",
+    "Uncategorized" : "Без категории",
     "Sample note" : "Пример заметки",
     "Tasks" : "Задачи",
+    "Nextcloud, a safe home for all your data" : "Nextcloud — безопасное место для всех ваших данных",
     "Development Mode" : "Режим разработки",
     "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "Вероятно, это приложение было установлено из источника, предназначенного для разработчиков. Настоятельно рекомендуется переустановить его из официального <a href=\"%1$s\">каталога приложений Nextcloud</a>. Инструкции по самостоятельной сборке приложения приведены в  <a href=\"%2$s\">руководстве для разработчиков</a>."
 },
