@@ -9,15 +9,15 @@ OC.L10N.register(
     "New note" : "Нова нотатка",
     "Distraction-free notes and writing" : "Нотатки та записи без відволікань",
     "Notes settings" : "Налаштування",
-    "Please see Nextcloud server log for details." : "Будь ласка, перегляньте журнал сервера Nextcloud для отримання додаткової інформації.",
+    "Please see Nextcloud server log for details." : "Будь ласка, перегляньте журнал сервера хмари Nextcloud для отримання додаткової інформації.",
     "Deleted {title}" : "Вилучено {title}",
     "Undo Delete" : "Повернути вилучення",
     "Note recovered" : "Примітку відновлено",
     "There are unsaved notes. Leaving the page will discard all changes!" : "Є незбережені нотатки. Якщо залишити сторінку, усі зміни буде скасовано!",
-    "_Deleted {number} note_::_Deleted {number} notes_" : ["Видалено {number} примітка","Видалено {number} приміток","Видалено {number} приміток","Видалено {number} приміток"],
-    "_Recovered {number} note_::_Recovered {number} notes_" : ["Відновлено {number} нотатка","Відновлено {number} нотаток","Відновлено {number} нотаток","Відновлено {number} нотаток"],
+    "_Deleted {number} note_::_Deleted {number} notes_" : ["Видалено {number} примітка","Видалено {number} приміток","Видалено {number} приміток","Вилучено {number} нотаток"],
+    "_Recovered {number} note_::_Recovered {number} notes_" : ["Відновлено {number} нотатку","Відновлено {number} нотаток","Відновлено {number} нотаток","Відновлено {number} нотаток"],
     "Basics" : "Простий",
-    "Write down your thoughts without any distractions." : "Записуйте свої думки, не відволікаючись.",
+    "Write down your thoughts without any distractions." : "Занотовуйте свої думки, не відволікаючись.",
     "Organize your notes in categories." : "Упорядкуйте нотатки за категоріями.",
     "Notes path" : "Шлях до нотаток",
     "Folder to store your notes" : "Каталог для збереження нотаток",
@@ -53,13 +53,13 @@ OC.L10N.register(
     "Select folder to link to" : "Виберіть каталог",
     "All notes" : "Усі нотатки",
     "Categories" : "Категорії",
-    "Create a sample note with Markdown" : "Створіть зразок примітки з Markdown",
+    "Create a sample note with Markdown" : "Створіть зразок примітки з використанням текстової розмітки",
     "No notes yet" : "Нотатки поки відсутні",
     "Upload image" : "Завантажити зображення",
     "Select an image" : "Виберіть зображення",
     "You cannot select images outside of your notes folder. Your notes folder is: {folder}" : "Ви не можете вибрати зображення за межами каталогу з нотатками. Ваш каталог нотаток: {folder}",
     "Wrong image" : "Недійсне зображення",
-    "The file was not uploaded. Check your server logs." : "Файл не було завантажено. Перевірте журнали свого сервера.",
+    "The file was not uploaded. Check your server logs." : "Файл не було завантажено. Перевірте журнали сервера.",
     "Install the app for your mobile phone in order to access your notes from everywhere." : "Встановіть мобільний застосунок для мобільного телефону, що дозволить отримувати доступ до нотаток звідусіль.",
     "Android app: {notes}" : "Додаток для Android: {notes}",
     "iOS app: {notes}" : "Додаток для iOS: {notes}",
@@ -68,31 +68,31 @@ OC.L10N.register(
     "This option can also be changed later on in the Notes app settings." : "Цю опцію можна буде змінити пізніше у налаштуваннях Нотаток.",
     "Keep plain Markdown editor" : "Використовувати простий редактор розмітки",
     "Use rich editor" : "Використовувати редактор з форматуванням",
-    "Share" : "Share",
+    "Share" : "Поділитися",
     "Change category" : "Змінити категорію",
-    "Rename" : "Rename",
+    "Rename" : "Перейменувати",
     "Rename note" : "Перейменувати нотатку",
-    "Delete note" : "Вилучити нотатку",
-    "Remove from favorites" : "Вилучено з улюбленого",
+    "Delete note" : "Вилучити",
+    "Remove from favorites" : "Прибрати зірочку",
     "Add to favorites" : "Додати зірочку",
     "Error while renaming note." : "Помилка під час перейменування нотатки.",
     "Error during preparing note for deletion." : "Помилка під час підготовки нотатки до вилучення.",
     "The note has been changed in another session. Please choose which version should be saved." : "Нотатку було змінено в іншому сеансі. Будь ласка, виберіть, яку версію потрібно зберегти.",
-    "Use version from server" : "Використовуйте віддалену версію",
+    "Use version from server" : "Використовувати віддалену версію",
     "Use current version" : "Використовувати поточну версію",
-    "Empty note" : "Порожня записка",
-    "Write …" : "Напишіть…",
+    "Empty note" : "Порожня нотатка",
+    "Write …" : "Напишіть …",
     "CTRL + /" : "CTRL + /",
     "Edit" : "Редагувати",
     "Preview" : "Перегляд",
     "Exit full screen" : "Вийти з повноекранного режиму",
     "Full screen" : "Повноекранний режим",
-    "Note is read-only. You cannot change it." : "Примітка доступна лише для читання. Ви не можете це змінити.",
-    "Save failed. Click to retry." : "Не вдалося зберегти. Натисніть, щоб повторити спробу.",
-    "Update conflict. Click for resolving manually." : "Конфлікт оновлень. Натисніть, щоб прийняти рішення вручну.",
+    "Note is read-only. You cannot change it." : "Нотатка доступна лише для читання. Ви не можете це змінити.",
+    "Save failed. Click to retry." : "Не вдалося зберегти. Клацніть, щоб повторити спробу.",
+    "Update conflict. Click for resolving manually." : "Конфлікт під час оновлення. Клацніть, щоб прийняти рішення вручну.",
     "Error from Nextcloud server: {msg}" : "Помилка сервера Nextcloud: {msg}",
     "Search for notes" : "Пошук нотаток",
-    "Loading …" : "Завантаження...",
+    "Loading …" : "Завантаження ...",
     "Find in all categories" : "Шукати в усіх категоріях",
     "Today" : "Сьогодні",
     "Yesterday" : "Вчора",
@@ -100,15 +100,15 @@ OC.L10N.register(
     "Last week" : "Минулого тижня",
     "This month" : "Цього місяця",
     "Last month" : "Минулого місяця",
-    "Use Markdown markups to style your text." : "Використовуйте розмітку Markdown, щоб стилізувати текст.",
-    "Start writing a note by clicking on “{newnote}” in the app navigation." : "Почніть писати нотатку, натиснувши «{newnote}» ​​у навігаційній панелі програми.",
-    "Note not found." : "Примітка не знайдена.",
-    "Note is locked." : "Примітка заблокована.",
+    "Use Markdown markups to style your text." : "Використовувати текстову розмітку для стилізації тексту.",
+    "Start writing a note by clicking on “{newnote}” in the app navigation." : "Почніть писати нотатку, для цього виберіть \"{newnote}\" ​​у навігаційній панелі застосунку.",
+    "Note not found." : "Нотатку не знайдено.",
+    "Note is locked." : "Нотатку заблоковано.",
     "Insufficient storage." : "Недостатньо місця для зберігання.",
-    "See JavaScript console and server log for details." : "Додаткову інформацію див. у консолі JavaScript і журналі сервера.",
+    "See JavaScript console and server log for details." : "Додаткову інформацію дивіться у консолі JavaScript та журналі сервера.",
     "Updating settings has failed." : "Не вдалося оновити налаштування.",
-    "Fetching notes for dashboard has failed." : "Не вдалося отримати нотатки для інформаційної панелі.",
-    "Fetching notes has failed." : "Помилка отримання нотаток.",
+    "Fetching notes for dashboard has failed." : "Не вдалося отримати нотатки у інформаційній панелі.",
+    "Fetching notes has failed." : "Помилка під час отримання нотаток.",
     "Fetching note {id} has failed." : "Не вдалося отримати нотатку {id}.",
     "Refreshing note {id} has failed." : "Не вдалося оновити нотатку {id}.",
     "Renaming note {id} has failed." : "Не вдалося перейменувати нотатку {id}.",
@@ -117,8 +117,8 @@ OC.L10N.register(
     "Updating title for note {id} has failed." : "Помилка оновлення назви нотатки {id}.",
     "Undo delete has failed for note {title}." : "Не вдалося скасувати вилучення нотатки {title}.",
     "Deleting note {id} has failed." : "Не вдалося вилучити нотатку {id}.",
-    "Toggling favorite for note {id} has failed." : "Помилка перемикання вподобаних нотаток {id}.",
-    "Updating the note's category has failed. Is the target directory writable?" : "Не вдалося оновити категорію нотатки. Чи доступний цільовий каталог для запису?",
+    "Toggling favorite for note {id} has failed." : "Помилка додавання зірочки до нотатки {id}.",
+    "Updating the note's category has failed. Is the target directory writable?" : "Не вдалося оновити категорію нотатки. Перевірте, чи доступний каталог нотаток для запису?",
     "Updating the category for note {id} has failed." : "Не вдалося оновити категорію для примітки {id}.",
     "Uncategorized" : "Некатегоризоване",
     "Sample note" : "Приклад нотатки",
